Staging: comedi: Remove comedi_driver typedef

Signed-off-by: Bill Pemberton <wfp5p@virginia.edu>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
diff --git a/drivers/staging/comedi/drivers/pcmmio.c b/drivers/staging/comedi/drivers/pcmmio.c
index 6af8637..0dcc099 100644
--- a/drivers/staging/comedi/drivers/pcmmio.c
+++ b/drivers/staging/comedi/drivers/pcmmio.c
@@ -259,7 +259,7 @@
 #define devpriv ((pcmmio_private *)dev->private)
 #define subpriv ((pcmmio_subdev_private *)s->private)
 /*
  * The comedi_driver structure tells the Comedi core module
  * which functions to call to configure/deconfigure (attach/detach)
  * the board, and also about the kernel module that contains
  * the device code.
@@ -267,7 +267,7 @@
 static int pcmmio_attach(struct comedi_device * dev, comedi_devconfig * it);
 static int pcmmio_detach(struct comedi_device * dev);
 
-static comedi_driver driver = {
+static struct comedi_driver driver = {
       driver_name:"pcmmio",
       module:THIS_MODULE,
       attach:pcmmio_attach,
@@ -259,7 +259,7 @@
 #define subpriv ((pcmmio_subdev_private *)s->private)
 /*
- * The comedi_driver structure tells the Comedi core module
+ * The struct comedi_driver structure tells the Comedi core module
  * which functions to call to configure/deconfigure (attach/detach)
  * the board, and also about the kernel module that contains